@@ -71,6 +71,7 @@ def associations(
     object: str = typer.Option(None, "--object", "-o"),
     entity: str = typer.Option(None, "--entity", "-e"),
     between: str = typer.Option(None, "--between"),
+    association_label: str = typer.Option(None, "--label"),
     limit: int = typer.Option(20, "--limit", "-l"),
     offset: int = typer.Option(0, "--offset"),
     update: bool = typer.Option(
@@ -92,6 +93,8 @@ def associations(
         subject: The subject of the association
         object: The object of the association
         entity: The subject or object of the association
+        between: The subject and object of the association
+        association_label: The label of the association
         limit: The number of associations to return
         offset: The offset of the first association to be retrieved
         fmt: The format of the output (TSV, YAML, JSON)
