@@ -6,8 +6,7 @@ from loguru import logger
 from pydantic import BaseModel
 
 from monarch_py.datamodels.solr import SolrQuery, SolrQueryResult, core
-from monarch_py.utils.utils import console
-from monarch_py.utils.utils import escape
+from monarch_py.utils.utils import console, escape
 
 
 class SolrService(BaseModel):
